import axios from 'axios';
import React from 'react';
import {grey400} from 'material-ui/styles/colors';
import PageBase from '../components/PageBase';
import {Link } from 'react-router'
import TextField from 'material-ui/TextField';
import SelectField from 'material-ui/SelectField';
import MenuItem from 'material-ui/MenuItem';
import RaisedButton from 'material-ui/RaisedButton';
import DatePicker from 'material-ui/DatePicker';
import Checkbox from 'material-ui/Checkbox';
import IconButton from 'material-ui/IconButton';
import CloseIcon from 'material-ui/svg-icons/navigation/close';
import Snackbar from 'material-ui/Snackbar';


let styles = {
  toggleDiv: {
    maxWidth: 300,
    marginTop: 40,
    marginBottom: 5
  },
  toggleLabel: {
    color: grey400,
    fontWeight: 100
  },
  buttons: {
    marginTop: 30,
    float: 'right'
  },
  saveButton: {
    marginLeft: 5
  },
  createSite: {
    marginRight: 25
  },
  imgBox : {
    height: 200,
    width: 'auto'
  },webtoolTable : {

    maxWidth: '700px',
    width:'100%',
    borderStyle: 'solid',   
    borderWidth: '1px',
    marginRight: 'auto',
    marginLeft: 'auto',          
    overflow: 'hidden',
    display:'inline-table',
    borderColor: ' rgba(0,0,0,0.2)'             
  },
  hideElement: {
      display:'none'
  }
};

//const apiUrl = "https://iqservice-stage.secure.local/api";
const apiUrl = "http://localhost:64824/api";
const autoBuildURL = "http://localhost:64824/api/IQ/BuildSite"


let _webtoolObject = {};

var getQueryString = function ( field, url ) {
  var href = url ? url : window.location.href;
  var reg = new RegExp( '[?&]' + field + '=([^&#]*)', 'i' );
  var string = reg.exec(href);
  return string ? string[1] : null;
};

let _alertMessage = "";

let initialLoadState = {};

class getSiteByID extends React.Component{

    constructor(props)
    {
        super(props)
        this.state = {
           SiteDetails: {contractDate:new Date(), cancelledDate:1, liveDate:new Date()}, 
           webtoolObject: _webtoolObject, 
           open: false,
           WebsiteOptions: {
             status:[], 
             network:[],
             template:[],
             instance:[],
             siteLocation:[],
             dns:[],
             toolsLocation:[],
             accountManager:[],
             webPackage:[]

            
          }          
          };     
        this.handleChange = this.handleTextChange.bind(this);
    }
    
    componentWillMount()
    {
      _webtoolObject = {
      mortgageFinder : false,
      mortgageTable : false,
      widgets : false,
      calculators : false,
      marketData:false,
      exchange:false,
      securedLoans: false,
      conveyancing:false,
      overseas:false
    }
    }

    componentDidMount() {  
      
      if (getQueryString('cd') != null &&
          getQueryString('cd') != undefined)
          {
         axios.get(apiUrl + '/IQ/' + getQueryString('id'),{withCredentials: true} )
        .then((response) => {
          this.setState({
             SiteDetails:response.data.websites,
             webtoolObject:  {
              mortgageFinder : response.data.websites.mortgageFinder,
              mortgageTable : response.data.websites.mortgageTable,
              widgets : response.data.websites.widgets,
              calculators : response.data.websites.calculators,
              marketData:response.data.websites.marketData,
              exchange:response.data.websites.exchange,
              securedLoans: response.data.websites.securedLoans,
              conveyancing:response.data.websites.conveyancing,
              overseas:response.data.websites.overseas,
              instance : response.data.websites.instance
            },
            WebsiteOptions: response.data.websiteOptions
               
          });
          initialLoadState = this.state;
          console.log(this.state);
         }
         
      )
    }
    }
        
    handleClose () { 
      this.setState({ open: false });
    }

    handleCreateSite()
    {

      console.log(initialLoadState.SiteDetails.fullBuildJson);

        axios({
          method:'post',
          url: autoBuildURL,
          withCredentials: true,
          crossDomain: true,
          headers: {
            'Accept': 'application/json',
            'Content-Type': 'application/json',
          },
          data: {fullBuildJson: initialLoadState.SiteDetails.fullBuildJson}
          
      }).then(() => {
        _alertMessage = "Site successfully created ",
        this.setState({open: true });

        this.setState({SiteDetails: {status: "Site Built", 
          accountManager: this.state.SiteDetails.accountManager,
          network: this.state.SiteDetails.network,
          template: this.state.SiteDetails.template,
          siteLocation: this.state.SiteDetails.siteLocation,
          dnsChoice: this.state.SiteDetails.dnsChoice   ,
          webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
          logoSrc: this.state.SiteDetails.logoSrc,
          contractDate : new Date(this.state.SiteDetails.contractDate),
          webPackage: this.state.SiteDetails.webPackage,
          liveDate : new Date(this.state.SiteDetails.liveDate),
          cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
          instance : this.state.SiteDetails.instance      
         }}); 

      }).catch((errorResponse) => {
        _alertMessage = "Error creating site, see console log for details",
        console.log(errorResponse);
        this.setState({open: true });
      })
    }

    //#region material-UI update hack methods as event.target.value doesn't work! :(
    handleTextChange(event) {
         
      var markerObj = this.state;

      //I know this looks weird having so many set states but is hack to fix Material_UI's lack ot target.value.

      this.setState({SiteDetails: event.target.value});
      
      this.setState({SiteDetails: {accountManager: markerObj.SiteDetails.accountManager,
                                   status: markerObj.SiteDetails.status,
                                   network: markerObj.SiteDetails.network,
                                   template: markerObj.SiteDetails.template,
                                   siteLocation: markerObj.SiteDetails.siteLocation,
                                   dnsChoice: markerObj.SiteDetails.dnsChoice,
                                   webtoolsLocation :markerObj.SiteDetails.webtoolsLocation,
                                   logoSrc: markerObj.SiteDetails.logoSrc,
                                   contractDate : new Date(markerObj.SiteDetails.contractDate),
                                   liveDate : new Date(markerObj.SiteDetails.liveDate),
                                   cancelledDate  : new Date(markerObj.SiteDetails.cancelledDate),
                                   webPackage: this.state.SiteDetails.webPackage,
                                   instance : this.state.SiteDetails.instance
                                  }}); 
    }


      handleCheckBoxChange(event)
      {
        var markerObj = this.state; 
        _webtoolObject = this.state.webtoolObject;

             
        if (_webtoolObject[event.target.value]){
          _webtoolObject[event.target.value] = false;      
        }
        else{
          _webtoolObject[event.target.value] = true;    
                     
        }  

        this.setState(markerObj);
        this.setState({SiteDetails:markerObj.SiteDetails, webtoolObject:_webtoolObject}); 
      }

      handleContractDateChange(category, date){      
        this.setState({SiteDetails: {accountManager: this.state.SiteDetails.accountManager,
          status: this.state.SiteDetails.status,
          network: this.state.SiteDetails.network,
          template: this.state.SiteDetails.template,
          siteLocation: this.state.SiteDetails.siteLocation,
          dnsChoice: this.state.SiteDetails.dnsChoice,
          webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
          logoSrc: this.state.SiteDetails.logoSrc,
          contractDate : new Date(date),
          webPackage: this.state.SiteDetails.webPackage,
          liveDate:new Date(this.state.SiteDetails.liveDate),
          cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
          instance : this.state.SiteDetails.instance
        }}); 
      }     
      handleLiveDateChange(category, date){      
        this.setState({SiteDetails: {accountManager: this.state.SiteDetails.accountManager,
          status: this.state.SiteDetails.status,
          network: this.state.SiteDetails.network,
          template: this.state.SiteDetails.template,
          siteLocation: this.state.SiteDetails.siteLocation,
          dnsChoice: this.state.SiteDetails.dnsChoice,
          webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
          logoSrc: this.state.SiteDetails.logoSrc,
          contractDate : new Date(this.state.SiteDetails.contractDate),
          liveDate:new Date(date),
          cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
          webPackage: this.state.SiteDetails.webPackage,
          instance : this.state.SiteDetails.instance
        }}); 
      }   
      handleCancelledDateChange(category, date){      
        this.setState({SiteDetails: {accountManager: this.state.SiteDetails.accountManager,
          status: this.state.SiteDetails.status,
          network: this.state.SiteDetails.network,
          template: this.state.SiteDetails.template,
          siteLocation: this.state.SiteDetails.siteLocation,
          dnsChoice: this.state.SiteDetails.dnsChoice,
          webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
          logoSrc: this.state.SiteDetails.logoSrc,
          contractDate : new Date(this.state.SiteDetails.contractDate),
          liveDate:new Date(this.state.SiteDetails.liveDate),
          cancelledDate : new Date(date),
          webPackage: this.state.SiteDetails.webPackage,
          instance : this.state.SiteDetails.instance
        }}); 
      }   



    handleAccountManagerChange(event, selectedIndex, optionValue) {
      this.setState({SiteDetails: {accountManager: optionValue,
                                   status: this.state.SiteDetails.status,
                                   network: this.state.SiteDetails.network,
                                   template: this.state.SiteDetails.template,
                                   siteLocation: this.state.SiteDetails.siteLocation,
                                   dnsChoice: this.state.SiteDetails.dnsChoice,
                                   webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                   logoSrc: this.state.SiteDetails.logoSrc,
                                   contractDate : new Date(this.state.SiteDetails.contractDate),
                                   webPackage: this.state.SiteDetails.webPackage,
                                   liveDate : new Date(this.state.SiteDetails.liveDate),
                                   cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                   instance : this.state.SiteDetails.instance
                                  }}); 
      }  

     handleStatusManagerChange(event, selectedIndex, optionValue) {
      this.setState({SiteDetails: {status: optionValue, 
                                   accountManager: this.state.SiteDetails.accountManager,
                                   network: this.state.SiteDetails.network,
                                   template: this.state.SiteDetails.template,
                                   siteLocation: this.state.SiteDetails.siteLocation,
                                   dnsChoice: this.state.SiteDetails.dnsChoice   ,
                                   webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                   logoSrc: this.state.SiteDetails.logoSrc,
                                   contractDate : new Date(this.state.SiteDetails.contractDate),
                                   webPackage: this.state.SiteDetails.webPackage,
                                   liveDate : new Date(this.state.SiteDetails.liveDate),
                                   cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                   instance : this.state.SiteDetails.instance      
                                  }}); 
      }

      handleNetworkManagerChange(event, selectedIndex, optionValue) {
        this.setState({SiteDetails: {status: this.state.SiteDetails.status, 
                                     accountManager: this.state.SiteDetails.accountManager,
                                     network: optionValue,
                                     template: this.state.SiteDetails.template,
                                     siteLocation: this.state.SiteDetails.siteLocation,
                                     dnsChoice: this.state.SiteDetails.dnsChoice,
                                     webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                     logoSrc: this.state.SiteDetails.logoSrc,
                                     contractDate : new Date(this.state.SiteDetails.contractDate),
                                     webPackage: this.state.SiteDetails.webPackage,
                                     liveDate : new Date(this.state.SiteDetails.liveDate),
                                     cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                     instance : this.state.SiteDetails.instance
                                    }}); 
        }

        handletemplateChange(event, selectedIndex, optionValue) {
          this.setState({SiteDetails: {template: optionValue, 
                                       status: this.state.SiteDetails.status, 
                                       accountManager: this.state.SiteDetails.accountManager,
                                       network: this.state.SiteDetails.network,
                                       siteLocation: this.state.SiteDetails.siteLocation,
                                       dnsChoice: this.state.SiteDetails.dnsChoice,
                                       webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                       logoSrc: this.state.SiteDetails.logoSrc,
                                       contractDate : new Date(this.state.SiteDetails.contractDate),
                                       webPackage: this.state.SiteDetails.webPackage,
                                       liveDate : new Date(this.state.SiteDetails.liveDate),
                                       cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                       instance : this.state.SiteDetails.instance
                                      }});
          }

          handleSiteLocationManagerChange(event, selectedIndex, optionValue) {
            this.setState({SiteDetails: {siteLocation: optionValue,
                                         template: this.state.SiteDetails.template, 
                                         status: this.state.SiteDetails.status, 
                                         accountManager: this.state.SiteDetails.accountManager,
                                         network: this.state.SiteDetails.network,
                                         dnsChoice: this.state.SiteDetails.dnsChoice,
                                         webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                         logoSrc: this.state.SiteDetails.logoSrc ,
                                         contractDate : new Date(this.state.SiteDetails.contractDate),
                                         webPackage: this.state.SiteDetails.webPackage ,
                                         liveDate : new Date(this.state.SiteDetails.liveDate),
                                         cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                         instance : this.state.SiteDetails.instance           
                                        }});
            }

            handleSiteDNSChange(event, selectedIndex, optionValue) {
              this.setState({SiteDetails: {
                                           dnsChoice: optionValue,
                                           siteLocation: this.state.SiteDetails.siteLocation,
                                           template: this.state.SiteDetails.template, 
                                           status: this.state.SiteDetails.status, 
                                           accountManager: this.state.SiteDetails.accountManager,
                                           network: this.state.SiteDetails.network,
                                           webtoolsLocation : this.state.SiteDetails.webtoolsLocation,
                                           logoSrc: this.state.SiteDetails.logoSrc,
                                           contractDate : new Date(this.state.SiteDetails.contractDate),
                                           webPackage: this.state.SiteDetails.webPackage,
                                           liveDate : new Date(this.state.SiteDetails.liveDate),
                                           cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                           instance : this.state.SiteDetails.instance
                                          }});
              }
              handleSiteWebtoolsLocationChange(event, selectedIndex, optionValue) {
                this.setState({SiteDetails: {
                                             webtoolsLocation: optionValue,
                                             dnsChoice: this.state.SiteDetails.dnsChoice,
                                             siteLocation: this.state.SiteDetails.siteLocation,
                                             template: this.state.SiteDetails.template, 
                                             status: this.state.SiteDetails.status, 
                                             accountManager: this.state.SiteDetails.accountManager,
                                             network: this.state.SiteDetails.network,
                                             logoSrc: this.state.SiteDetails.logoSrc,
                                             contractDate : new Date(this.state.SiteDetails.contractDate),
                                             webPackage: this.state.SiteDetails.webPackage,
                                             liveDate : new Date(this.state.SiteDetails.liveDate),
                                             cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                             instance : this.state.SiteDetails.instance
                                            
                                            }});
                }

                handleSitewebPackageChange(event, selectedIndex, optionValue) {
                  this.setState({SiteDetails: {accountManager: this.state.SiteDetails.accountManager,
                                               status: this.state.SiteDetails.status,
                                               network: this.state.SiteDetails.network,
                                               template: this.state.SiteDetails.template,
                                               siteLocation: this.state.SiteDetails.siteLocation,
                                               dnsChoice: this.state.SiteDetails.dnsChoice,
                                               webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                               logoSrc: this.state.SiteDetails.logoSrc,
                                               contractDate : new Date(this.state.SiteDetails.contractDate),
                                               webPackage: optionValue,
                                               liveDate : new Date(this.state.SiteDetails.liveDate),
                                               cancelledDate : new Date(this.state.SiteDetails.cancelledDate),
                                               instance : this.state.SiteDetails.instance
                                              }}); 
                  }  



                  handleInstanceChange(event, selectedIndex, optionValue) {
                    this.setState({SiteDetails: {instance: optionValue,
                                                 accountManager: this.state.SiteDetails.accountManager,
                                                 status: this.state.SiteDetails.status,
                                                 network: this.state.SiteDetails.network,
                                                 template: this.state.SiteDetails.template,
                                                 siteLocation: this.state.SiteDetails.siteLocation,
                                                 dnsChoice: this.state.SiteDetails.dnsChoice,
                                                 webtoolsLocation :this.state.SiteDetails.webtoolsLocation,
                                                 logoSrc: this.state.SiteDetails.logoSrc,
                                                 contractDate : new Date(this.state.SiteDetails.contractDate),
                                                 webPackage: this.state.SiteDetails.webPackage,
                                                 liveDate : new Date(this.state.SiteDetails.liveDate),
                                                 cancelledDate : new Date(this.state.SiteDetails.cancelledDate)
                                                }}); 
                    } 



//#endregion

                getLogoInformation(evt)
                {
                  var reader = new FileReader();
                  var file = evt.target.files[0];
              
                  reader.onload = function() {
                    var dataURL = reader.result;
                    var output = document.getElementById('output');
                    output.src = dataURL;
                  };
                  reader.readAsDataURL(file);
                }

                handleSubmit(event) {                 
                  event.preventDefault();            
                 
                 let exportObject = {                                                                  
                              companyName : document.getElementById("companyName").value,                    
                              clientName :document.getElementById("clientName").value,                    
                              clientEmail : document.getElementById("clientEmail").value,                    
                              contractDate :this.refs.contractDate.state.date.getTime(),
                              status : this.refs.status.props.value,                   
                              liveURL : document.getElementById("liveURL").value,                    
                              network : this.refs.network.props.value,               
                              template : this.refs.template.props.value,
                              siteLocation: this.refs.siteLocation.props.value,
                              dnsChoice :  this.refs.dnsChoice.props.value,                   
                              webtoolsLocation : this.refs.webtoolsLocation.props.value,                 
                              accountManager: this.refs.accountManager.props.value,
                              logoSrc: document.getElementById("output").src,
                              phoneNumber: document.getElementById("phoneNumber").value,
                              webPackage: this.refs.webPackage.props.value,
                              initialFee: document.getElementById("initialFee").value,
                              monthlyFee: document.getElementById("monthlyFee").value,
                              stagingUrl: document.getElementById("stagingUrl").value,
                              liveDate:  this.refs.liveDate.state.date.getTime(),
                              cancelledDate: this.refs.cancelledDate.state.date.getTime(),
                              mortgageFinder : this.state.webtoolObject.mortgageFinder,
                              mortgageTable :this.state.webtoolObject.mortgageTable,
                              widgets : this.state.webtoolObject.widgets,
                              calculators : this.state.webtoolObject.calculators,
                              marketData:this.state.webtoolObject.marketData,
                              exchange:this.state.webtoolObject.exchange,
                              securedLoans: this.state.webtoolObject.securedLoans,
                              conveyancing:this.state.webtoolObject.conveyancing,
                              overseas:this.state.webtoolObject.overseas,
                              instance: this.refs.instance.props.value
                            }          
                  initialLoadState.SiteDetails != undefined ? exportObject.fullBuildJson = initialLoadState.SiteDetails.fullBuildJson : exportObject.fullBuildJson = "Uploaded manually"                 

                  let putURL = apiUrl + "/IQ/" + getQueryString('id');
                  let postUrl = apiUrl + "/IQ/";
            
                  axios({
                      method: getQueryString('id') > 0 ? 'put' : 'post',
                      url: getQueryString('id') > 0 ? putURL : postUrl,
                      data: exportObject,
                      withCredentials: true
                  }).then(() => {
                    _alertMessage = "Save Complete",
                    this.setState({open: true });
                  }).catch(() => {
                    _alertMessage = "Error saving Record",
                    this.setState({open: true });
                  })
                }                
    render(){
      

      
      const site =( 

<PageBase title={getQueryString('id') ? "Company Information" : "Create New Company"}
              navigation="Application / Form Page">


<div>
        <Snackbar       
          open={this.state.open}
          autoHideDuration={2000}        
          message={<span id="message-id">{_alertMessage}</span>}
          onClose={this.handleClose.bind(this)}       
          action={[
            <IconButton
              key="close"
              aria-label="Close"
              color="inherit"
              className="close"
              onClick={this.handleClose.bind(this)}
            >
              <CloseIcon />
            </IconButton>,
          ]}

        />
      </div>
      <form action="" onSubmit={this.handleSubmit.bind(this)}>     
        <TextField          
          floatingLabelText="Company"
          id="companyName"      
          fullWidth={true}          
          value =  {this.state.SiteDetails.companyName}
          onChange={this.handleTextChange.bind(this)}
          floatingLabelFixed = {true}
          required={true}
        />

        <TextField
          floatingLabelFixed = {true}
          id="clientName"
          floatingLabelText="Main Contact"
          fullWidth={true}
          value = {this.state.SiteDetails.clientName}
          onChange={this.handleTextChange.bind(this)}
          required={true}
        />

          <TextField
          floatingLabelFixed = {true}
          floatingLabelText="Client Email"
          id="clientEmail"
          type="email"
          fullWidth={true}
          value = {this.state.SiteDetails.clientEmail}
          onChange={this.handleTextChange.bind(this)}
          required={true}
        />

          <DatePicker
          floatingLabelFixed = {true}
          floatingLabelText="Contract Date"
          ref="contractDate"
          id ="contract-date"
          fullWidth={true}         
          value = {new Date(this.state.SiteDetails.contractDate || 0)}
          onChange = {this.handleContractDateChange.bind(this)}
        />    

     
     

        <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="Status"
          ref="status"
          value = {this.state.SiteDetails.status || "Not Specified" }
          onChange = {this.handleStatusManagerChange.bind(this)}  
          fullWidth={true}>          
          {
            this.state.WebsiteOptions.status.map ((x,i) => (<MenuItem value={x} key={i} primaryText={x}/>))    
          }

        </SelectField>

        <DatePicker
          style={this.state.SiteDetails.status != "Cancelled" ? styles.hideElement : null}
          floatingLabelFixed = {true}
          floatingLabelText="Cancelled Date"
          ref="cancelledDate"
          id ="cancelled-date"
          fullWidth={true}         
          value = {new Date(this.state.SiteDetails.cancelledDate || 0)}
          onChange = {this.handleCancelledDateChange.bind(this)}
        />   
           
         <DatePicker
         style={this.state.SiteDetails.status != "Live" ? styles.hideElement : null}
          floatingLabelFixed = {true}
          floatingLabelText="Live Date"
          ref="liveDate"
          id ="contract-date"
          fullWidth={true}         
          value = {new Date(this.state.SiteDetails.liveDate || 0)}
          onChange = {this.handleLiveDateChange.bind(this)}
        /> 


          <TextField
          floatingLabelFixed = {true}
          floatingLabelText="Staging Url"
          fullWidth={true}
          id = "stagingUrl"
          value = {this.state.SiteDetails.stagingUrl}
          onChange={this.handleTextChange.bind(this)}
          required={true}
        />

        <TextField
           floatingLabelFixed = {true}
          floatingLabelText="Live URL"
          fullWidth={true}
          id = "liveURL"
          value = {this.state.SiteDetails.liveURL}
          onChange={this.handleTextChange.bind(this)}
          required={true}
        />
 
      <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="Network"
          value = {this.state.SiteDetails.network || "Not Specified"}
          ref = "network"
          onChange = {this.handleNetworkManagerChange.bind(this)}  
          required={true}
          fullWidth={true}>                 
          {this.state.WebsiteOptions.network.map((x,i) => (<MenuItem key={i} value={x}  primaryText={x}/>))}

        </SelectField>


        <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="Template Choice"
          value = {this.state.SiteDetails.template || "Not Specified"}
          ref = "template"
          onChange = {this.handletemplateChange.bind(this)}  
          required={true}
          fullWidth={true}>          
          {this.state.WebsiteOptions.template.map((x,i) => (<MenuItem key={i} value={x} primaryText={x}/> ))}

        </SelectField>

     
        <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="Instance"
          value = {this.state.SiteDetails.instance || "Not Specified"}
          ref = "instance"
          required={true}
          onChange = {this.handleInstanceChange.bind(this)}  
          fullWidth={true}>
          {this.state.WebsiteOptions.instance.map((x,i) => (<MenuItem key={i} value={x}  primaryText={x}/>))}             
        </SelectField>


        
      <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="Site Location"
          value = {this.state.SiteDetails.siteLocation || "Not Specified"}
          ref = "siteLocation"
          required={true}
          onChange = {this.handleSiteLocationManagerChange.bind(this)}  
          fullWidth={true}>          
          {this.state.WebsiteOptions.siteLocation.map((x,i) => (<MenuItem key={i} value={x} primaryText={x}/>)  )}         
        </SelectField>


      <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="DNS Choice"
          value = {this.state.SiteDetails.dnsChoice || "Not Specified"} 
          ref = "dnsChoice"
          onChange = {this.handleSiteDNSChange.bind(this)}  
          fullWidth={true}>          
          {this.state.WebsiteOptions.dns.map((x,i) => (<MenuItem key={i} value={x} primaryText={x}/>))}
        </SelectField>    
        
      <SelectField
          floatingLabelFixed = {true}
          required={true}
          floatingLabelText="Webtools Location"
          value = {this.state.SiteDetails.webtoolsLocation || "Not Specified"} 
          ref = "webtoolsLocation"
          onChange = {this.handleSiteWebtoolsLocationChange.bind(this)}  
          fullWidth={true}>          
          {this.state.WebsiteOptions.toolsLocation.map((x,i) =>  (<MenuItem key={i} value={x}  primaryText={x}/> ))}           
        </SelectField>


        <SelectField
          floatingLabelFixed = {true}
          floatingLabelText="Account Manager"
          value = {this.state.SiteDetails.accountManager || "Not Specified"} 
          ref = "accountManager"
          onChange = {this.handleAccountManagerChange.bind(this)}  
          fullWidth={true}> 
          {this.state.WebsiteOptions.accountManager.map((x,i) => (<MenuItem key={i} value={x} primaryText={x}/>))}
           </SelectField>

        <TextField
           floatingLabelFixed = {true}
          floatingLabelText="Phone Number"
          fullWidth={true}
          id = "phoneNumber"
          value = {this.state.SiteDetails.phoneNumber}
          onChange={this.handleTextChange.bind(this)}
          required={true}
          type="tel"
        />
    

    <SelectField
          floatingLabelFixed = {true}
          required={true}
          floatingLabelText="Web Package"
          value = {this.state.SiteDetails.webPackage || "Not Specified"} 
          ref = "webPackage"
          onChange = {this.handleSitewebPackageChange.bind(this)}  
          fullWidth={true}>   
          {this.state.WebsiteOptions.webPackage.map((x,i) => (<MenuItem key={i} value={x}  primaryText={x}/> ))}                         
        </SelectField>

     
        
        <TextField
          floatingLabelFixed = {true}
          floatingLabelText="Initial Fee"
          fullWidth={true}
          id = "initialFee"
          value = {this.state.SiteDetails.initialFee}
          onChange={this.handleTextChange.bind(this)}
          required={true}
          type="number"
        />

        <TextField
          floatingLabelFixed = {true}
          floatingLabelText="Monthly Fee"
          fullWidth={true}
          id = "monthlyFee"
          value = {this.state.SiteDetails.monthlyFee}
          onChange={this.handleTextChange.bind(this)}
          required={true}
          type="number"
        />

      <Checkbox 
           label="Terms and Conditions accepted"      
           checked={true}           
           onCheck={this.handleCheckBoxChange.bind(this)}
        />

        <br/>
        <br/>
        <label><strong>Webtools</strong></label>
        <br/>
        <table style={styles.webtoolTable}>
         <tr>
          <td>
          <Checkbox 
           label="Mortgage Tables" 
           checked = {this.state.webtoolObject.mortgageTable || false}
           value = "mortgageTable"
           onCheck={this.handleCheckBoxChange.bind(this)}
        />
          </td>
          <td>
          <Checkbox 
           label="Mortgage Finder"
           checked={this.state.webtoolObject.mortgageFinder || false} 
           value = "mortgageFinder"
           onCheck={this.handleCheckBoxChange.bind(this)}
          
        />
         </td>
         <td>
        <Checkbox 
           label="Mortgage Widgets"      
           checked={this.state.webtoolObject.widgets || false}
           value = "widgets"
           onCheck={this.handleCheckBoxChange.bind(this)}
        />
        </td>
  </tr>

<tr>
        <td>
        <Checkbox 
           label="Finanical Calculators"
           checked={this.state.webtoolObject.calculators || false}
           value = "calculators"
           
           onCheck={this.handleCheckBoxChange.bind(this)}
        />
        </td>
            <td>
            <Checkbox 
           label="Market Data"
           checked={this.state.webtoolObject.marketData || false}
           value = "marketData"
           onCheck={this.handleCheckBoxChange.bind(this)}
        />
           </td>
           <td>
        <Checkbox 
           label="Exchange"  
           checked={this.state.webtoolObject.exchange || false}   
           value = "exchange"   
           onCheck={this.handleCheckBoxChange.bind(this)}  
        />

       
          </td>
          </tr>
          <tr>
          <td>
        <Checkbox 
           label="Secured Loans"
           checked={this.state.webtoolObject.securedLoans || false}
           value = "securedLoans"
           onCheck={this.handleCheckBoxChange.bind(this)}
        />
        </td>
        <td>
        <Checkbox 
           label="Conveyancing" 
           checked={this.state.webtoolObject.conveyancing || false}  
           value = "conveyancing" 
           onCheck={this.handleCheckBoxChange.bind(this)}        
        />
         </td>
         <td>
         <Checkbox 
           label="Overseas Mortgages" 
           checked={this.state.webtoolObject.overseas || false}          
           value= "overseas"
           onCheck={this.handleCheckBoxChange.bind(this)}
        />
          </td>         
      </tr>
        </table>

  <br/>
  <br/>

        <label><strong>Logo</strong></label>  <br/>
        <label>Upload file:</label> <br/>
      
        <input ref="file" type="file" name="file" 
                              className="upload-file" 
                              id="file"
                              onChange={this.getLogoInformation.bind(this)}
                              encType="multipart/form-data" 
                              />
        

          
      <div>      
        <img style={styles.imgBox} id="output" src={this.state.SiteDetails.logoSrc} alt="No logo uploaded"/>
      </div>

    
        <div style={styles.buttons}>


        <RaisedButton label="Build website"                  
                        type="button"
                        onClick={this.handleCreateSite.bind(this)}
                        primary={true}
                        disabled={this.state.SiteDetails.status != "In Build"}   
                        style={styles.createSite}                     
                        />

          <Link to="/table">
            <RaisedButton label="Cancel"/>
          </Link>


          <RaisedButton label="Save"
                        style={styles.saveButton}
                        type="submit"
                        primary={true}/>
        </div>
      </form>
    </PageBase>

)   
    return site;

}
}


export default getSiteByID;
