import {Table, TableBody, TableHeader, TableHeaderColumn, TableRow, TableRowColumn} from 'material-ui/Table';
import axios from 'axios';
import React from 'react';
import FloatingActionButton from 'material-ui/FloatingActionButton';
import Open from 'material-ui/svg-icons/action/search'
import CreateNew from 'material-ui/svg-icons/content/add'
import ContentDelete from 'material-ui/svg-icons/content/clear';
import {pink500, grey200, grey500} from 'material-ui/styles/colors';
import PageBase from '../components/PageBase';
import {Link} from 'react-router';
import { red100 } from 'material-ui/styles/colors';
import ReactPaginate from 'react-paginate';


var getQueryString = function ( field, url ) {
  var href = url ? url : window.location.href;
  var reg = new RegExp( '[?&]' + field + '=([^&#]*)', 'i' );
  var string = reg.exec(href);
  return string ? string[1] : null;
};

//const apiUrl = "https://iqservice-stage.secure.local/api";
const apiUrl = "http://localhost:64824/api";

//Fields
let _paginationKey = 0;
let _currentPage = 0;
let _skipcount = 20;
let _sortOption = "id";
let _reverseResults = false;

let _filterObject = {
  status: {},
  templates:{
    r1: true,
    r2: true,
    r3: true,
    r4: true,
    r5: true,
    r6: true,
    selfCreated: true,
    custom: true,
    legacy: true
  },
  network: {
    direct: true,
    sesame: true,
    pms: true,
    intrinsic: true,
    intrinsicRestricted: true,
    stonebridge: true,
    personalTouch: true,
    firstComplete: true,
    other: true
  }
}

class getWebsitesData extends React.Component{

    constructor()
    {
        super()
        this.state = { websites: [],
                      filterObject: _filterObject
        };
    }
    
    componentWillMount()
    {

        //Default
      _filterObject.status =  {
        inBuild: true,
        withClient : true,
        changeRequest : true,
        live : true,
        cancelled : true,
        suspended: true
      };

      if (getQueryString('filterBy') == "Live"){
        _filterObject.status =  {
          inBuild: false,
          withClient : false,
          changeRequest : false,
          live : true,
          cancelled : false,
          suspended: false
        };
      }
      if (getQueryString('filterBy') == "InBuild"){
        _filterObject.status =  {
          inBuild: true,
          withClient : false,
          changeRequest : false,
          live : false,
          cancelled : false,
          suspended: false
        };
      }
      if (getQueryString('filterBy') == "DDM"){
        _filterObject.status =  {
          inBuild: false,
          withClient : false,
          changeRequest : false,
          live : false,
          cancelled : false,
          suspended: false
        };
      }
      if (getQueryString('filterBy') == "WithClient"){
        _filterObject.status =  {
          inBuild: false,
          withClient : true,
          changeRequest : false,
          live : false,
          cancelled : false,
          suspended: false
        };
      }   
    }
    
    componentDidMount() {
        this.getlistdata();
    }
            DeleteCompany(id,name)
            {
              if (confirm("Delete " + name + "?") === true) {
                axios({
                  method: 'delete',
                  url: apiUrl + '/IQ/' + id,
                  withCredentials: true          
                }).then(this.getlistdata.bind(this));
            } 
           }

           forcePaginatioReset()
           {
                         //Force pagination reset
                         _currentPage = 0;
                         _paginationKey++; 
           }

          handleStatusFiltedChange(event)
            {          
              if (_filterObject.status[event.target.value]){
                _filterObject.status[event.target.value] = false;
              }
              else{
                _filterObject.status[event.target.value] = true;                
              }  
              this.setState({filterObject:_filterObject}); 
              
              this.forcePaginatioReset();
              this.getlistdata();    
            }

            handleTemplatesFiltedChange(event)
            {          
              console.log(event.target.value);
              if (_filterObject.templates[event.target.value]){
                _filterObject.templates[event.target.value] = false;
              }
              else{
                _filterObject.templates[event.target.value] = true;                
              }  
              this.setState({filterObject:_filterObject});
              this.forcePaginatioReset();
              this.getlistdata();
            }

            handleNetworkFiltedChange(event)
            {          
              if (_filterObject.network[event.target.value]){
                _filterObject.network[event.target.value] = false;
              }
              else{
                _filterObject.network[event.target.value] = true;                
              }  
              this.setState({filterObject:_filterObject});  
              this.forcePaginatioReset();    
              this.getlistdata();
            }

          sortResults(sortOption){
             
              //Toggle Reverse results if same menu item clicked
                if (sortOption === _sortOption )
                {                  
                  if (_reverseResults == true)_reverseResults = false;
                  else _reverseResults = true;                
                }
               _sortOption = sortOption;
                            
              //Force  pagination reset
              this.forcePaginatioReset();
              this.getlistdata();
          }

           handleSearch()
           {
            this.forcePaginatioReset();
            this.getlistdata();
           }

           getlistdata(){
               
             axios.get(apiUrl + '/IQ/GetListViewData', {
              params: {
               skipcount: _skipcount, 
               page: _currentPage,
               sortBy: _sortOption,
               ReverseResults: _reverseResults,
               SearchValue: getQueryString('Search'),
               filtersJson: JSON.stringify(this.state.filterObject)
              },
              withCredentials: true
            })
                .then((response) => {
                  this.setState({
                      websites:response.data.websites,
                      resultCount:response.data.resultCount,
                      filterObject: _filterObject
                  }) 
               })
          }  

    onPageChange(event){               
          _currentPage = event.selected * _skipcount;      
          this.getlistdata();     
    }

    
    render(){
      let csvParams = "?skipcount=" + _skipcount +      
                       "&page=" + _currentPage +  
                       "&sortBy=" + _sortOption +
                       "&ReverseResults=" + _reverseResults +
                       "&filtersJson="
                       + JSON.stringify(this.state.filterObject);


      //If search value in query string then add the search parameter to CsvParams
      if (getQueryString('Search')){
        csvParams += "&SearchValue=" + getQueryString('Search')
      }

      
      var _ = this;
      document.onkeypress = function (e) {
        if (e.key == 'Enter')
        {
          setTimeout(function() { _.handleSearch() }.bind(this), 10);
        }       
    };

      const Headerstyles = {
        floatingActionButton: {
          margin: 0,
          top: 'auto',
          right: 20,
          bottom: 20,
          left: 'auto',
          position: 'fixed',
        },
        editButton: {
          fill: grey500
        },
        columns: {
          id: {
            width: '5%'
          },
          companyName: {
            width: '20%'
          },
          ContractDate: {
            width: '30%'
          },
          status: {
            width: '21%'
          },
          edit: {
            width: '11%'
          },
          delete: {
            width: '10%'
          }
        }
      };
      

        const styles = {
            floatingActionButton: {
              margin: 0,
              top: 'auto',
              right: 20,
              bottom: 20,
              left: 'auto',
              position: 'fixed',
            },
            editButton: {
              fill: grey500
            },
            delButton: {
              fill: grey500
               
            }
            ,
            columns: {
              id: {
                width: '5%'
              },
              name: {
                width: '20%'
              },
              price: {
                width: '30%'
              },
              category: {
                width: '21%'
              },
              edit: {
                width: '11%'
              },
              delete: {
                width: '10%'
              }
            }, filterChecks : {

              width: '30%',
              borderStyle: 'solid',
              borderWidth: '1px',
              marginRight: 'auto',
              marginLeft: 'auto',          
              overflow: 'hidden',
              display:'inline-table',
              margin:'10px 10px',
              borderColor: ' rgba(0,0,0,0.2)'           
            }
          };

const sites =(
  <PageBase title="Websites"    
  navigation="Application / Table Page">

<div>     
    <div>
    <table style={styles.filterChecks}>
    <h2>Status</h2>
    <tr>
        <td>
           <input type="checkBox" 
                  checked={this.state.filterObject.status.inBuild}             
                  id="In-Build" 
                  onChange={this.handleStatusFiltedChange.bind(this)} 
                  value="inBuild"           
                  />                   
            <label htmlFor="In-Build"> In Build</label>
          </td>
     
        <td>
           <input type="checkBox" 
                  checked={this.state.filterObject.status.withClient} 
                  id="With-Client" 
                  onChange={this.handleStatusFiltedChange.bind(this)} 
                  value="withClient"       
                  />
           <label htmlFor="With-Client">With Client for Review</label>
        </td> 
          
    </tr>
    <tr>
       <td>
          <input type="checkBox" 
                checked={this.state.filterObject.status.changeRequest}   
                id="Change-Request"
                value="changeRequest"
                onChange={this.handleStatusFiltedChange.bind(this)} 
                />
          <label htmlFor="Change-Request"> Change Request</label>
        </td>
        <td> 
          <input type="checkBox" 
                checked={this.state.filterObject.status.live}    
                id="Live" 
                value="live"  
                onChange={this.handleStatusFiltedChange.bind(this)} 
                />
          
          <label htmlFor="Live">Live</label></td>
 
    </tr> 
    <tr>
      <td> 
        <input type="checkBox" 
        checked={this.state.filterObject.status.cancelled}   
        id="Cancelled" 
        value="cancelled"
        onChange={this.handleStatusFiltedChange.bind(this)} 
        />
        <label htmlFor="Cancelled">Cancelled</label>
      </td>
      <td>
           <input type="checkBox" 
           checked={this.state.filterObject.status.suspended}    
           id="Suspended" 
           value="suspended"
           onChange={this.handleStatusFiltedChange.bind(this)} 
           /> 
           <label htmlFor="Suspended">Suspended</label>
      </td>
    </tr>  
  </table>
  <table style={styles.filterChecks}>
  <h2>Templates</h2>
    <tr>
      <td> 
        <input type="checkBox" checked={this.state.filterObject.templates.r1} id="r1" value="r1" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
        <label htmlFor="r1">R1</label>
      </td>
      <td> 
        <input type="checkBox" checked={this.state.filterObject.templates.r2} id="r2" value="r2" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
        <label htmlFor="r2">R2</label>
          
      </td>
         <input type="checkBox" checked={this.state.filterObject.templates.r3} id="r3" value="r3" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
         <label htmlFor="r3">R3</label>
    </tr>
    <tr>
      <td>
      <input type="checkBox" checked={this.state.filterObject.templates.r4} id="r4" value="r4" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
         <label htmlFor="r4">R4</label>
      </td>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.templates.r5} id="r5" value="r5" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
          <label htmlFor="r5">R5</label>
       </td>
      <td> 
      <input type="checkBox" checked={this.state.filterObject.templates.r6} id="r6" value="r6" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
          <label htmlFor="r6">R6</label>

      </td>
    </tr>
    <tr>
      <td> 
           <input type="checkBox" checked={this.state.filterObject.templates.selfCreated} id="selfCreated" value="selfCreated" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
          <label htmlFor="selfCreated">Self-Created</label>
     </td>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.templates.custom} id="custom" value="custom" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
          <label htmlFor="custom">Custom</label>     
      </td>
      <td>
           <input type="checkBox" checked={this.state.filterObject.templates.legacy} id="legacy" value="legacy" onChange={this.handleTemplatesFiltedChange.bind(this)}/>
          <label htmlFor="legacy">Legacy/Other</label>       
      </td>
    </tr>
  </table>

  <table style={styles.filterChecks}>
  <h2>Network</h2>
    <tr>
      <td> 
        
        <input type="checkBox" checked={this.state.filterObject.network.direct} id="direct" value="direct" onChange={this.handleNetworkFiltedChange.bind(this)}/>
        <label htmlFor="direct">Direct</label>
      
      </td>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.network.sesame} id="sesame" value="sesame" onChange={this.handleNetworkFiltedChange.bind(this)}/>
          <label htmlFor="sesame">Sesame</label>
      </td>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.network.pms} id="pms" value="pms" onChange={this.handleNetworkFiltedChange.bind(this)}/>
          <label htmlFor="pms">PMS</label>
        </td>
    </tr>
    <tr>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.network.intrinsic} id="intrinsic" value="intrinsic" onChange={this.handleNetworkFiltedChange.bind(this)}/>    
          <label htmlFor="intrinsic">Intrinsic</label>

      </td>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.network.intrinsicRestricted} id="intrinsicRestricted" value="intrinsicRestricted" onChange={this.handleNetworkFiltedChange.bind(this)}/>    
          <label htmlFor="intrinsicRestricted">Intrinsic Restricted</label>      
       </td>
      <td> 
          <input type="checkBox" checked={this.state.filterObject.network.stonebridge} id="stonebridge" value="stonebridge" onChange={this.handleNetworkFiltedChange.bind(this)}/>    
          <label htmlFor="stonebridge">Stonebridge</label>  
       </td>
    </tr>
    <tr>
      <td>
          <input type="checkBox" checked={this.state.filterObject.network.personalTouch} id="personalTouch" value="personalTouch" onChange={this.handleNetworkFiltedChange.bind(this)}/>    
          <label htmlFor="personalTouch">Personal Touch</label>  
      </td>
      <td> 
      <input type="checkBox" checked={this.state.filterObject.network.firstComplete} id="firstComplete" value="firstComplete" onChange={this.handleNetworkFiltedChange.bind(this)}/>    
      <label htmlFor="firstComplete">First Complete</label>  
      </td>
      <td>
        <input type="checkBox" checked={this.state.filterObject.network.other} id="other" value="other" onChange={this.handleNetworkFiltedChange.bind(this)}/>    
        <label htmlFor="other">Other</label>          
      </td>
    </tr>
  </table>
    </div>  
    
      

<Link to="/form" >
<FloatingActionButton style={styles.floatingActionButton} backgroundColor={pink500}>
<CreateNew />            
</FloatingActionButton>
</Link>
<Table>
<TableHeader> 
<TableRow>
  <TableHeaderColumn style={Headerstyles.columns.id}><a href="javascript:void(0);" onClick={this.sortResults.bind(this,"id")}>ID</a></TableHeaderColumn>
  <TableHeaderColumn style={Headerstyles.columns.companyName}><a href="javascript:void(0);" onClick={this.sortResults.bind(this,"companyname")}>Company Name</a></TableHeaderColumn>
  <TableHeaderColumn style={Headerstyles.columns.ContractDate}><a href="javascript:void(0);" onClick={this.sortResults.bind(this,"contractdate")}> Contract Date</a></TableHeaderColumn>
  <TableHeaderColumn style={Headerstyles.columns.status}><a href="javascript:void(0);" onClick={this.sortResults.bind(this,"status")}> Current Status </a></TableHeaderColumn>
  <TableHeaderColumn style={Headerstyles.columns.edit}>More info</TableHeaderColumn>
  <TableHeaderColumn style={Headerstyles.columns.delete}>Delete</TableHeaderColumn>
</TableRow>
</TableHeader>

        <TableBody>
        {this.state.websites.map(item =>
          <TableRow key={item.id}>
            <TableRowColumn style={styles.columns.id}>{item.id}</TableRowColumn>
            <TableRowColumn style={styles.columns.name}>{item.companyName}</TableRowColumn>
            <TableRowColumn style={styles.columns.price}>{new Date(item.contractDate).toString()}</TableRowColumn>
            <TableRowColumn style={styles.columns.category}>{item.status}</TableRowColumn>
            <TableRowColumn style={styles.columns.edit}>           
              <Link className="button" to={{ pathname: '/form', query: {id:item.id, cd:item.contractDate}  }}>
                <FloatingActionButton zDepth={0}
                                      mini={true}
                                      backgroundColor={grey200}
                                      iconStyle={styles.editButton}>
                  <Open  />
                </FloatingActionButton>
              </Link>
            </TableRowColumn>     
            <TableRowColumn style={styles.columns.delete}>   
            <FloatingActionButton zDepth={0}
                                      mini={true}
                                      backgroundColor={red100}
                                      iconStyle={styles.delButton}                                                                  
                                      >
                  <ContentDelete onClick={this.DeleteCompany.bind(this,item.id, item.companyName)} /> 
              </FloatingActionButton> 
                </TableRowColumn>
                      
          </TableRow>
        )}         
       </TableBody>
   
        </Table>    
             <div className="commentBox">       
        <ReactPaginate previousLabel={"previous"}
                      onPageChange={this.onPageChange.bind(this)}
                       nextLabel={"next"}
                       breakLabel={<a href="">...</a>}
                       breakClassName={"break-me"}
                       pageCount={this.state.resultCount / _skipcount}
                       marginPagesDisplayed={2}
                       pageRangeDisplayed={5}                      
                       containerClassName={"pagination"}
                       subContainerClassName={"pages pagination"}
                       activeClassName={"active"}
                       key={_paginationKey} />

        
        <a href={"http://localhost:64824/api/IQ/GenerateCsvReport" + csvParams} >Export to CSV</a>

      </div>
      </div>
 
    </PageBase> 
)
    return sites;

}
}
export default getWebsitesData;
