import React from 'react';
import {cyan600, pink600, purple600, orange600 } from 'material-ui/styles/colors';

import Face from 'material-ui/svg-icons/action/face';
import ThumbUp from 'material-ui/svg-icons/action/thumb-up';
import HourGlass from 'material-ui/svg-icons/action/hourglass-empty'
import Build from 'material-ui/svg-icons/action/build';
import InfoBox from '../components/dashboard/InfoBox';
import NewOrders from '../components/dashboard/NewOrders';
import MonthlySales from '../components/dashboard/MonthlySales';
import BrowserUsage from '../components/dashboard/BrowserUsage';
import RecentlyProducts from '../components/dashboard/RecentlyProducts';
import globalStyles from '../styles';
import Data from '../data';
import axios from 'axios';
import ChevronRight from 'material-ui/svg-icons/navigation/chevron-right';
import {Link} from 'react-router';

//const apiUrl = "https://iqservice-stage.secure.local/api";
const apiUrl = "http://localhost:64824/api";

class DashboardPage extends React.Component
{
  
  constructor()
  {
    super();
    this.state = { dashboardData : { 
                                      StatusStats:[{name:'Live', value: "Default" }],
                                      InstanceStats:[{name: 'Direct', value: "Default", color: cyan600, icon: <ChevronRight/>}],
                                      TemplateStats:[{name: 'R1', uv: "Default"}],
                                      RecentOrders:[]
                                     }
   }  
  }

    componentDidMount(){
      axios.get(apiUrl + '/IQ/GetDashBoardData', {
        withCredentials: true  
      })
          .then((response) => {
            this.setState({
                dashboardData:response.data  
            })       
         })
    }

    

    render()
    {    

     let instanceStats = [
        {name: 'Direct', value: this.state.dashboardData.InstanceStats.Direct, color: cyan600, icon: <ChevronRight/>},
        {name: 'PMS', value: this.state.dashboardData.InstanceStats.PMS, color: pink600, icon: <ChevronRight/>},
        {name: 'Sesame', value: this.state.dashboardData.InstanceStats.Sesame, color: purple600, icon: <ChevronRight/>},
      ];

      let templateStats = [
        {name: 'R1', uv: this.state.dashboardData.TemplateStats.R1},
        {name: 'R2', uv: this.state.dashboardData.TemplateStats.R2},
        {name: 'R3', uv: this.state.dashboardData.TemplateStats.R3},
        {name: 'R4', uv: this.state.dashboardData.TemplateStats.R4},
        {name: 'R5', uv: this.state.dashboardData.TemplateStats.R5},
        {name: 'R6', uv: this.state.dashboardData.TemplateStats.R6},
        {name: 'Self-created', uv: this.state.dashboardData.TemplateStats.SelfCreated},
        {name: 'Custom', uv: this.state.dashboardData.TemplateStats.Custom},
        {name: 'Legacy', uv: this.state.dashboardData.TemplateStats.OldSites}       
      ];


      const dashBoardLayout = (
        <div>
          <h3 style={globalStyles.navigation}>Application / Dashboard</h3>

          <div className="row">

            <div className="col-xs-12 col-sm-6 col-md-3 col-lg-3 m-b-15 ">

            <Link className="button" to={{ pathname: '/table', query: {filterBy:'Live'}  }}>
              <InfoBox Icon={ThumbUp}
                      color={pink600}
                      title="Live sites"
                      value={this.state.dashboardData.StatusStats.Live}
              />
              </Link>
            </div>

            <div className="col-xs-12 col-sm-6 col-md-3 col-lg-3 m-b-15 ">
            <Link className="button" to={{ pathname: '/table', query: {filterBy:'InBuild'}  }}>
              <InfoBox Icon={Build}
                      color={cyan600}
                      title="In Build"
                      value={this.state.dashboardData.StatusStats.InBuild}
              />
             </Link>
            </div>

            <div className="col-xs-12 col-sm-6 col-md-3 col-lg-3 m-b-15 ">
            <Link className="button" to={{ pathname: '/table', query: {filterBy:'DDM'}  }}>
              <InfoBox Icon={HourGlass}
                      color={purple600}
                      title="Awaiting DDM"
                      value={this.state.dashboardData.StatusStats.AwaitingDDM}
              />
              </Link>
            </div>

            <div className="col-xs-12 col-sm-6 col-md-3 col-lg-3 m-b-15 ">
            <Link className="button" to={{ pathname: '/table', query: {filterBy:'WithClient'}  }}>
              <InfoBox Icon={Face}
                      color={orange600}
                      title="With client for review"
                      value={this.state.dashboardData.StatusStats.InReview}
              />
            </Link>
            </div>
          </div>

          <div className="row">
            <div className="col-xs-12 col-sm-6 col-md-6 col-lg-6 col-md m-b-15">
              <NewOrders data={Data.dashBoardPage.newOrders}/>
            </div>

            <div className="col-xs-12 col-sm-6 col-md-6 col-lg-6 m-b-15">
              <MonthlySales data={templateStats}/>
            </div>
          </div>

          <div className="row">
            <div className="col-xs-12 col-sm-12 col-md-6 col-lg-6 m-b-15 ">
              <RecentlyProducts data={this.state.dashboardData.RecentOrders}/>
            </div>

            <div className="col-xs-12 col-sm-12 col-md-6 col-lg-6 m-b-15 ">
              <BrowserUsage data={instanceStats}/>
            </div>
          </div>
        </div>
      );
        return dashBoardLayout;
    }

}



export default DashboardPage;
